/**
 * Copyright 2006 (C) Bernd Bruegge, Timo Wolf - TU Muenchen
 * http://wwwbruegge.in.tum.de/Asteroids
 * 
 * This file is part of the Asteroids Teaching Design Pattern Project.
 * 
 * Asteroids is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * Asteroids is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * Asteroids; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 */
package de.tum.in.wwwbruegge.asteroids;

import java.applet.Applet;
import java.awt.Image;
import java.awt.MediaTracker;
import java.awt.Toolkit;
import java.net.URL;

import javax.swing.JPanel;

import de.tum.in.wwwbruegge.asteroids.control.Referee;
import de.tum.in.wwwbruegge.asteroids.solidbodies.Rocket;
import de.tum.in.wwwbruegge.asteroids.solidbodies.SmallAsteroid;
import de.tum.in.wwwbruegge.asteroids.solidbodies.SolidBody;
import de.tum.in.wwwbruegge.asteroids.solidbodies.SpaceShuttle;
import de.tum.in.wwwbruegge.asteroids.ui.Game;

/**
 * @author Timo Wolf
 */
public class Start {

	public static void main(String[] args) {

		try {
			SolidBody.DEFAULT_BODY = loadImage("asteroid.gif");
			SpaceShuttle.DEFAULT_BODY = loadImage("spaceshuttle.gif");
			Rocket.DEFAULT_BODY = loadImage("rocket.gif");
			SmallAsteroid.DEFAULT_BODY = loadImage("smallasteroid.gif");
			Referee.MUSIC = Applet.newAudioClip(Start.class
					.getResource("Music.wav"));

			Referee.BANG = Applet.newAudioClip(Start.class
					.getResource("Bang.au"));

		} catch (Exception e) {
			e.printStackTrace();
			System.exit(-1);
		}

		Game game = new Game();
		game.pack();
		game.setVisible(true);
		Referee.getInstance().initGame();
	}

	private static Image loadImage(String name) throws Exception {
		URL url = Start.class.getResource(name);
		MediaTracker m = new MediaTracker(new JPanel());
		Image img = Toolkit.getDefaultToolkit().getImage(url);
		m.addImage(img, 0);
		m.waitForAll();
		return img;
	}
}
