/**
 * Copyright 2006 (C) Bernd Bruegge, Timo Wolf - TU Muenchen
 * http://wwwbruegge.in.tum.de/Asteroids
 * 
 * This file is part of the Asteroids Teaching Design Pattern Project.
 * 
 * Asteroids is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * Asteroids is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * Asteroids; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 */
package de.tum.in.wwwbruegge.asteroids.ui;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JToolBar;

import de.tum.in.wwwbruegge.asteroids.solidbodies.SpaceShuttle;
import de.tum.in.wwwbruegge.asteroids.ui.instruments.Body;
import de.tum.in.wwwbruegge.asteroids.ui.instruments.GPS;
import de.tum.in.wwwbruegge.asteroids.ui.instruments.Speedometer;

/**
 * @author Timo Wolf
 */
public class InstrumentPanel extends JToolBar {

	private Body bodyView;

	private Speedometer speedometer;

	private GPS gps;

	private SpaceShuttle spaceshuttle;

	public InstrumentPanel(SpaceShuttle theSpaceShuttle) {
		super(JToolBar.VERTICAL);
		setFloatable(false);
		this.spaceshuttle = theSpaceShuttle;

		bodyView = new Body(theSpaceShuttle);
		theSpaceShuttle.subscribe(bodyView);
		add(bodyView);

		speedometer = new Speedometer(theSpaceShuttle);
		theSpaceShuttle.subscribe(speedometer);
		add(speedometer);

		gps = new GPS(theSpaceShuttle);
		theSpaceShuttle.subscribe(gps);
		add(gps);

		JButton externalInstrumentPanel = new JButton("new Window");
		externalInstrumentPanel.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				final JFrame window = new JFrame("Instruments");
				final InstrumentPanel newInstrumentPanel = new InstrumentPanel(
						spaceshuttle);
				window.getContentPane().add(newInstrumentPanel);

				window.addWindowListener(new WindowAdapter() {
					public void windowClosing(WindowEvent e) {
						window.setVisible(false);
						newInstrumentPanel.unsubscribeInstruments();
					}
				});

				window.pack();
				window.setVisible(true);
			}
		});
		add(externalInstrumentPanel);
	}

	private void unsubscribeInstruments() {
		this.spaceshuttle.unsubscribe(bodyView);
		this.spaceshuttle.unsubscribe(speedometer);
		this.spaceshuttle.unsubscribe(gps);
	}

	public Dimension getPreferredSize() {
		Dimension d = super.getPreferredSize();
		return new Dimension(300, d.height);
	}

	public Dimension getMinimumSize() {
		Dimension d = super.getMinimumSize();
		return new Dimension(300, d.height);
	}

	public Dimension getMaximumSize() {
		Dimension d = super.getMaximumSize();
		return new Dimension(300, d.height);
	}
}
