/**
 * Copyright 2006 (C) Bernd Bruegge, Timo Wolf - TU Muenchen
 * http://wwwbruegge.in.tum.de/Asteroids
 * 
 * This file is part of the Asteroids Teaching Design Pattern Project.
 * 
 * Asteroids is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * Asteroids is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * Asteroids; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 */
package de.tum.in.wwwbruegge.asteroids.ui;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JButton;
import javax.swing.JOptionPane;
import javax.swing.JToolBar;

import de.tum.in.wwwbruegge.asteroids.control.Referee;

/**
 * @author Timo Wolf
 */
public class ToolBar extends JToolBar {
	private Action startBumperAction;

	private Action stopBumperAction;

	private static ToolBar INSTANCE;

	public static ToolBar getInstance() {
		if (INSTANCE == null) {
			INSTANCE = new ToolBar();
		}
		return INSTANCE;
	}

	private ToolBar() {
		super();
		setFloatable(false);
		initActions();
		JButton button = add(startBumperAction);
		button.setFocusable(false);
		button = add(stopBumperAction);
		button.setFocusable(false);
		enableButtons();
	}

	private void initActions() {
		startBumperAction = new AbstractAction("start") {
			public void actionPerformed(ActionEvent e) {
				Referee.getInstance().startGame();
			}
		};

		stopBumperAction = new AbstractAction("stop") {
			public void actionPerformed(ActionEvent e) {
				Referee.getInstance().stopGame();
				int ret = JOptionPane.showConfirmDialog(null,
						"Do you really want to stop the game ?",
						"Stop Game Confirmation", JOptionPane.YES_NO_OPTION);
				if (ret == 0) {
					Referee.getInstance().initGame();

				} else {
					Referee.getInstance().startGame();
				}
			}
		};
	}

	public void enableButtons() {
		if (Referee.getInstance().isRunning()) {
			startBumperAction.setEnabled(false);
			stopBumperAction.setEnabled(true);
		} else {
			startBumperAction.setEnabled(true);
			stopBumperAction.setEnabled(false);
		}
	}
}
